@@ -5,27 +5,31 @@ import time as t
 
 """
 为了让右边的警示消失，改了好多语法和习惯。
-0.0.4版将”锁定“函数的递归改为循环
+0.0.4版将”锁定“函数的递归改为循环。
+0.0.8版返回点击不同区域的次数。
 """
 
 
-def suo_ding(name, region=(0, 0, 1920, 1080), confidence=0.7):  # 锁定目标图片并捕捉（点击），区域默认全屏。当函数后有注释时，开头空两行。
+def suo_ding(name, dianjicishu=1, region=(0, 0, 1920, 1080), confidence=0.7):  # 锁定目标图片并捕捉（点击），区域默认全屏。当函数后有注释时，开头空两行。
     f = False
+    f1, f2, f3, f4, n = (0, 0, 0, 0, 0)
     while True:
         location = p.locateOnScreen(name, region=region, confidence=confidence, grayscale=True)
         # confidence像素差异、grayscale灰度，返回一个元组。
         if location:
             f = True
             x1, y1, w, h = location  # 图片左上角的坐标，图片的宽、高。
+            if x1 > f1+1.1*f3 or x1 < f1-0.1*f3:  # 检测第二次点击位置是否不在同一位置，横坐标
+                n+=1
             x2 = x1+w
             y2 = y1+h  # 计算得到图片右下角的坐标。
-            X = r.randint(int(x1 + 0.1 * (x2 - x1)), int(x2 - 0.1 * (x2 - x1)))  # 将坐标区域向图片中心靠近，即图片边缘区域不点击。
-            Y = r.randint(int(y1 + 0.1 * (y2 - y1)), int(y2 - 0.1 * (y2 - y1)))  # 获取随机位置X,Y。
+            X = r.randint(int(x1 + 0.1 * w), int(x2 - 0.1 * w))  # 将坐标区域向图片中心靠近，即图片边缘区域不点击。
+            Y = r.randint(int(y1 + 0.1 * h), int(y2 - 0.1 * h))  # 获取随机位置X,Y。
             bu_zhuo(X, Y)
-        else:
+        elif n == dianjicishu:
             break
     if f:
-        return True
+        return n
     else:
         return False
 
